@@ -2,14 +2,16 @@ use crate::error::*;
 use std::path::{Path, PathBuf};
 use std::process::Command;
 
+/// ## Measure the estimated download sizes of APKs in an APK set
+///
 /// To measure the estimated download sizes of APKs in an APK set as they would be served
-/// compressed over-the-wire, use the get-size total command:
+/// compressed over-the-wire, use the `get-size total` command:
 ///
 /// ```xml
 /// bundletool get-size total --apks=/MyApp/my_app.apks
 /// ```
 ///
-/// You can modify the behavior of the get-size total command using the following flags:
+/// You can modify the behavior of the `get-size total` command using the following flags:
 pub struct GetSizeTotal {
     apks: PathBuf,
     device_spec: Option<PathBuf>,
@@ -40,22 +42,22 @@ impl GetSizeTotal {
     }
 
     /// Specifies the dimensions used when computing the size estimates.
-    /// Accepts a comma-separated list of: SDK, ABI, SCREEN_DENSITY, and LANGUAGE. To
-    /// measure across all dimensions, specify ALL.
+    /// Accepts a comma-separated list of: `SDK`, `ABI`, `SCREEN_DENSITY`, and `LANGUAGE`.
+    /// To measure across all dimensions, specify `ALL`.
     pub fn dimensions(&mut self, dimensions: String) -> &mut Self {
         self.dimensions = Some(dimensions);
         self
     }
 
     /// Measures the download size of the instant-enabled APKs instead of the installable
-    /// APKs. By default, bundletool measures the installable APK download sizes
+    /// APKs. By default, `bundletool` measures the installable APK download sizes
     pub fn instant(&mut self, instant: bool) -> &mut Self {
         self.instant = instant;
         self
     }
 
     /// Specifies a comma-separated list of modules in the APK set to consider in the
-    /// measurement. The bundletool command automatically includes any dependent modules
+    /// measurement. The `bundletool` command automatically includes any dependent modules
     /// for the specified set. By default, the command measures the download size of
     /// all modules installed during the first download.
     pub fn modules(&mut self, modules: String) -> &mut Self {
@@ -69,7 +71,7 @@ impl GetSizeTotal {
         if let Ok(bundletool_path) = std::env::var("BUNDLETOOL_PATH") {
             get_size_total.arg(bundletool_path);
         } else {
-            return Err(Error::BundletoolNotFound);
+            return Err(Error::BundletoolNotFound.into());
         }
         get_size_total.arg("get-size");
         get_size_total.arg("total");
